import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Item {
    property bool canChangeParameters: config.acl.value <= ParamGlobal.ADMINISTRATOR
    property bool canChangeProgram: config.acl.value <= ParamGlobal.TECHNICIAN

    HipotProcess {
        id: process
        parameters: hipot
        canbusHipot: canbus.hipot
        halObj: hal
        configObj: config

        Component.onCompleted: isUnderVoltage = Qt.binding(function() { return running; })
    }

    Image {
        anchors {
            top: parent.top
            left: parent.left
            leftMargin: 5
        }

        source: "bg_central.png"

        Item {
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: parent.left
            }
            width: 359

            /*****************
            * Result message *
            *****************/
            TestStatus {
                anchors {
                    top: parent.top
                    bottom: graphzone.top
                    left: parent.left
                    right: graphzone.right
                }
                state: process.status
            }

            /*************
            * Graph zone *
            *************/
            Item {
                id: graphzone

                height: graph.height

                anchors {
                    horizontalCenter: parent.horizontalCenter
                    bottom: parent.bottom
                    bottomMargin: 10 + 40
                }

                HipotGraph {
                    id: graph

                    anchors {
                        bottom: parent.bottom
                        bottomMargin: 10
                        horizontalCenter: parent.horizontalCenter
                    }

                    width: 300
                    height: 150

                    nbPhases: hipot.nbPhases.value
                    valuePhase1: hipot.expertPhases[0].voltage.value
                    valuePhase2: hipot.expertPhases[1].voltage.value
                    valuePhase3: hipot.expertPhases[2].voltage.value
                    valuePhase4: hipot.expertPhases[3].voltage.value
                    valuePhase5: hipot.expertPhases[4].voltage.value
                    valuePhase6: hipot.expertPhases[5].voltage.value
                    valuePhase7: hipot.expertPhases[6].voltage.value

                    stepStatus1: process.phases[0].status
                    stepStatus2: process.phases[1].status
                    stepStatus3: process.phases[2].status
                    stepStatus4: process.phases[3].status
                    stepStatus5: process.phases[4].status
                    stepStatus6: process.phases[5].status
                    stepStatus7: process.phases[6].status

                    phasePercent: process.stepPercent
                    currentPhase: process.currentPhase
                }
            }
        }

        /*******************
        * Live report zone *
        *******************/
        MeasureCaroussel {
            id: livereport_internal

            anchors {
                top: parent.top
                bottom: parent.bottom
                left: parent.left
                leftMargin: 359
                right: parent.right
            }

            u: process.voltageText
            it: process.currentTotalText
            ir: process.currentRealText
        }
    }


    /*********************************
    * Right bar (params, list, help) *
    *********************************/
    RightBar {
        id: rightbar
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
        enabled_help: !isUnderVoltage
        enabled_list: !isUnderVoltage && canChangeProgram
        enabled_settings: !isUnderVoltage && canChangeParameters
    }

    /*******************
    * Parameters panel *
    *******************/
    Rectangle {
        id: paramspanel
        property bool opened: true

        anchors {
            left: parent.left
            right: rightbar.left
            rightMargin: 10
        }

        y: opened ? 0 : height - 40
        height: parent.height
        width: parent.width - 20

        radius: 10
        border.width: 2
        border.color: UiConfig.colors.border
        color: UiConfig.colors.bg_active

        MouseArea {
            anchors.fill: parent
            onClicked: parent.opened = !parent.opened

            // Auto hide
            property int processStatus: process.status
            onProcessStatusChanged: {
                if (processStatus == HipotProcessPhaseReport.NORMAL)
                    parent.opened = false;
            }
        }

        Text {
            id: textParameters
            anchors {
                top: parent.top
                topMargin: 10
                horizontalCenter: parent.horizontalCenter
            }
            text: qsTr("Parameters")
            color: "#ffffff"
        }

        Button {
            anchors {
                top: parent.top
                topMargin: 6
                right: parent.right
                rightMargin: 15
            }
            enabled: !isUnderVoltage
            text: qsTr("%1 phases").arg(hipot.nbPhases.value)
            onClicked: popup().editParam(hipot.nbPhases)
            visible: paramspanel.opened
        }

        Button {
            anchors {
                top: parent.top
                topMargin: 6
                left: parent.left
                leftMargin: 15
            }
            text: paramspanel.opened ? qsTr("Close") : qsTr("Open")
            onClicked: parent.opened = !parent.opened
        }

        Item {
            id: innerParmaeters
            anchors {
                top: textParameters.bottom
                left: parent.left
                right: parent.right
                bottom: parent.bottom
                margins: 10
                topMargin: 20
            }

            Repeater {
                id: btnsRepeater
                model: hipot.nbPhases.value
                delegate: Rectangle {
                    property var params: hipot.expertPhases[index]
                    x: 5 + index * (width + 10)
                    width: innerParmaeters.width / hipot.nbPhases.value - 10
                    height: innerParmaeters.height
                    radius: 10
                    color: UiConfig.colors.border

                    /******************
                    * Parameters list *
                    ******************/
                    Column {
                        anchors.fill: parent
                        anchors.margins: 2
                        spacing: 7

                        ErrorButton {
                            width: parent.width
                            height: 60
                            enabled: !isUnderVoltage
                            text: params.deltaICurrent.name + "\n" + params.deltaICurrent.value + " " + params.deltaICurrent.unit
                            onClicked: popup().editParam(params.deltaICurrent)
                            state: {
                                var st = "";
                                if (process.phases[index].deltaIStatus == HipotProcessPhaseReport.ERROR) st = "error";
                                else if (process.phases[index].deltaIStatus == HipotProcessPhaseReport.FAIL) st = "fail";
                                return st;
                            }
                        }

                        ErrorButton {
                            width: parent.width
                            height: 60
                            enabled: !isUnderVoltage
                            text: qsTr("Imax") + "\n" + params.imaxTotal.value + " " + params.imaxTotal.unit
                            onClicked: popup().editParam(params.imaxTotal)
                            state: {
                                var st = "";
                                if (process.phases[index].iMaxStatus == HipotProcessPhaseReport.ERROR) st = "error";
                                else if (process.phases[index].iMaxStatus == HipotProcessPhaseReport.FAIL) st = "fail";
                                return st;
                            }
                        }

                        Button {
                            width: parent.width
                            enabled: !isUnderVoltage
                            text: params.voltage.value + " " + params.voltage.unit
                            onClicked: popup().editParam(params.voltage)
                        }

                        Button {
                            width: parent.width
                            height: 80
                            enabled: !isUnderVoltage
                            srcImage: {
                                var dir = 0;
                                if (index == 0)
                                    dir = params.voltage.value;
                                else
                                    dir = params.voltage.value - hipot.expertPhases[index-1].voltage.value

                                return (dir > 0) ? "expert_arrow_up.png" : (dir < 0) ? "expert_arrow_down.png" : "expert_arrow_level.png"
                            }
                            onClicked: popup().editParam(params.voltage)
                        }

                        Button {
                            width: parent.width
                            enabled: !isUnderVoltage
                            text: params.time.value + " " + params.time.unit
                            onClicked: popup().editParam(params.time)
                        }
                    }
                }
            }
        }

        Behavior on y {
            NumberAnimation { easing.type: Easing.InOutCubic }
        }
    }
}
